@@ -1,4 +1,4 @@
-# Copyright 2015-2016 Google Inc. All Rights Reserved.
+# Copyright 2015-2017 Google Inc. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -260,17 +260,15 @@ def _MarkLinesToFormat(uwlines, lines):
 
 
 def _DisableYAPF(line):
-  return (re.search(DISABLE_PATTERN, line.split('\n')[0].strip(),
-                    re.IGNORECASE) or re.search(DISABLE_PATTERN,
-                                                line.split('\n')[-1].strip(),
-                                                re.IGNORECASE))
+  return (
+      re.search(DISABLE_PATTERN, line.split('\n')[0].strip(), re.IGNORECASE) or
+      re.search(DISABLE_PATTERN, line.split('\n')[-1].strip(), re.IGNORECASE))
 
 
 def _EnableYAPF(line):
-  return (re.search(ENABLE_PATTERN, line.split('\n')[0].strip(),
-                    re.IGNORECASE) or re.search(ENABLE_PATTERN,
-                                                line.split('\n')[-1].strip(),
-                                                re.IGNORECASE))
+  return (
+      re.search(ENABLE_PATTERN, line.split('\n')[0].strip(), re.IGNORECASE) or
+      re.search(ENABLE_PATTERN, line.split('\n')[-1].strip(), re.IGNORECASE))
 
 
 def _GetUnifiedDiff(before, after, filename='code'):
