@@ -105,7 +105,8 @@ class GetCommandLineFilesTest(unittest.TestCase):
     tdir3 = self._make_test_dir('test3/foo/bar/bas/xxx')
     files = [
         os.path.join(tdir1, 'testfile1.py'),
-        os.path.join(tdir2, 'testfile2.py'), os.path.join(tdir3, 'testfile3.py')
+        os.path.join(tdir2, 'testfile2.py'),
+        os.path.join(tdir3, 'testfile3.py'),
     ]
     _touch_files(files)
 
@@ -121,7 +122,8 @@ class GetCommandLineFilesTest(unittest.TestCase):
     tdir3 = self._make_test_dir('test3/foo/bar/bas/xxx')
     files = [
         os.path.join(tdir1, 'testfile1.py'),
-        os.path.join(tdir2, 'testfile2.py'), os.path.join(tdir3, 'testfile3.py')
+        os.path.join(tdir2, 'testfile2.py'),
+        os.path.join(tdir3, 'testfile3.py'),
     ]
     _touch_files(files)
 
@@ -131,7 +133,7 @@ class GetCommandLineFilesTest(unittest.TestCase):
                 [self.test_tmpdir], recursive=True, exclude=['*test*3.py'])),
         sorted([
             os.path.join(tdir1, 'testfile1.py'),
-            os.path.join(tdir2, 'testfile2.py')
+            os.path.join(tdir2, 'testfile2.py'),
         ]))
 
 
