@@ -1206,8 +1206,8 @@ xxxxxxxxxxx, yyyyyyyyyyyy, vvvvvvvvv)
                 if True:
                   if True:
                     if row[4] is None or row[5] is None:
-                      bbbbbbbbbbbbb['..............'] = row[5] if row[
-                          5] is not None else 5
+                      bbbbbbbbbbbbb['..............'] = row[
+                          5] if row[5] is not None else 5
         """)
     uwlines = yapf_test_helper.ParseAndUnwrap(code)
     self.assertCodeEqual(code, reformatter.Reformat(uwlines))
@@ -1273,7 +1273,8 @@ xxxxxxxxxxx, yyyyyyyyyyyy, vvvvvvvvv)
     code = textwrap.dedent("""\
       a = f(
           a="something",
-          b="something requiring comment which is quite long",  # comment about b (pushes line over 79)
+          b=
+          "something requiring comment which is quite long",  # comment about b (pushes line over 79)
           c="something else, about which comment doesn't make sense")
       """)
     uwlines = yapf_test_helper.ParseAndUnwrap(code)
@@ -1292,10 +1293,11 @@ xxxxxxxxxxx, yyyyyyyyyyyy, vvvvvvvvv)
 
   def testIfExpressionWithFunctionCall(self):
     code = textwrap.dedent("""\
-      if x or z.y(a,
-                  c,
-                  aaaaaaaaaaaaaaaaaaaaa=aaaaaaaaaaaaaaaaaa,
-                  bbbbbbbbbbbbbbbbbbbbb=bbbbbbbbbbbbbbbbbb):
+      if x or z.y(
+          a,
+          c,
+          aaaaaaaaaaaaaaaaaaaaa=aaaaaaaaaaaaaaaaaa,
+          bbbbbbbbbbbbbbbbbbbbb=bbbbbbbbbbbbbbbbbb):
         pass
       """)
     uwlines = yapf_test_helper.ParseAndUnwrap(code)
@@ -1571,6 +1573,33 @@ xxxxxxxxxxx, yyyyyyyyyyyy, vvvvvvvvv)
     finally:
       style.SetGlobalStyle(style.CreateChromiumStyle())
 
+  def testStableInlinedDictionaryFormatting(self):
+    try:
+      style.SetGlobalStyle(style.CreatePEP8Style())
+      unformatted_code = textwrap.dedent("""\
+          def _():
+              url = "http://{0}/axis-cgi/admin/param.cgi?{1}".format(
+                  value, urllib.urlencode({'action': 'update', 'parameter': value}))
+          """)
+      expected_formatted_code = textwrap.dedent("""\
+          def _():
+              url = "http://{0}/axis-cgi/admin/param.cgi?{1}".format(
+                  value, urllib.urlencode({
+                      'action': 'update',
+                      'parameter': value
+                  }))
+          """)
+
+      uwlines = yapf_test_helper.ParseAndUnwrap(unformatted_code)
+      reformatted_code = reformatter.Reformat(uwlines)
+      self.assertCodeEqual(expected_formatted_code, reformatted_code)
+
+      uwlines = yapf_test_helper.ParseAndUnwrap(reformatted_code)
+      reformatted_code = reformatter.Reformat(uwlines)
+      self.assertCodeEqual(expected_formatted_code, reformatted_code)
+    finally:
+      style.SetGlobalStyle(style.CreateChromiumStyle())
+
   def testDontSplitKeywordValueArguments(self):
     unformatted_code = textwrap.dedent("""\
         def mark_game_scored(gid):
@@ -1671,8 +1700,8 @@ xxxxxxxxxxx, yyyyyyyyyyyy, vvvvvvvvv)
               if True:
                 if True:
                   if True:
-                    boxes[id_] = np.concatenate(
-                        (points.min(axis=0), qoints.max(axis=0)))
+                    boxes[id_] = np.concatenate((points.min(axis=0),
+                                                 qoints.max(axis=0)))
         """)
     uwlines = yapf_test_helper.ParseAndUnwrap(unformatted_code)
     self.assertCodeEqual(expected_formatted_code, reformatter.Reformat(uwlines))
@@ -1952,9 +1981,9 @@ xxxxxxxxxxx, yyyyyyyyyyyy, vvvvvvvvv)
     code = textwrap.dedent("""\
         class _():
 
-          @mock.patch.dict(
-              os.environ,
-              {'HTTP_' + xsrf._XSRF_TOKEN_HEADER.replace('-', '_'): 'atoken'})
+          @mock.patch.dict(os.environ, {
+              'HTTP_' + xsrf._XSRF_TOKEN_HEADER.replace('-', '_'): 'atoken'
+          })
           def _():
             pass
 
