@@ -1,4 +1,4 @@
-# Copyright 2016 Google Inc. All Rights Reserved.
+# Copyright 2016-2017 Google Inc. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -28,6 +28,97 @@ class BuganizerFixes(yapf_test_helper.YAPFTest):
   def setUpClass(cls):
     style.SetGlobalStyle(style.CreateChromiumStyle())
 
+  def testB35212469(self):
+    unformatted_code = textwrap.dedent("""\
+        def _():
+          X = {
+            'retain': {
+                'loadtest':  # This is a comment in the middle of a dictionary entry
+                    ('/some/path/to/a/file/that/is/needed/by/this/process')
+              }
+          }
+        """)
+    expected_formatted_code = textwrap.dedent("""\
+        def _():
+          X = {
+              'retain': {
+                  'loadtest':  # This is a comment in the middle of a dictionary entry
+                      ('/some/path/to/a/file/that/is/needed/by/this/process')
+              }
+          }
+        """)
+    uwlines = yapf_test_helper.ParseAndUnwrap(unformatted_code)
+    self.assertCodeEqual(expected_formatted_code, reformatter.Reformat(uwlines))
+
+  def testB31063453(self):
+    unformatted_code = textwrap.dedent("""\
+        def _():
+          while ((not mpede_proc) or ((time_time() - last_modified) < FLAGS_boot_idle_timeout)):
+            pass
+        """)
+    expected_formatted_code = textwrap.dedent("""\
+        def _():
+          while ((not mpede_proc) or
+                 ((time_time() - last_modified) < FLAGS_boot_idle_timeout)):
+            pass
+        """)
+    uwlines = yapf_test_helper.ParseAndUnwrap(unformatted_code)
+    self.assertCodeEqual(expected_formatted_code, reformatter.Reformat(uwlines))
+
+  def testB35021894(self):
+    unformatted_code = textwrap.dedent("""\
+        def _():
+          labelacl = Env(qa={
+              'read': 'name/some-type-of-very-long-name-for-reading-perms',
+              'modify': 'name/some-other-type-of-very-long-name-for-modifying'
+          },
+                         prod={
+                            'read': 'name/some-type-of-very-long-name-for-reading-perms',
+                            'modify': 'name/some-other-type-of-very-long-name-for-modifying'
+                         })
+        """)
+    expected_formatted_code = textwrap.dedent("""\
+        def _():
+          labelacl = Env(
+              qa={
+                  'read': 'name/some-type-of-very-long-name-for-reading-perms',
+                  'modify': 'name/some-other-type-of-very-long-name-for-modifying'
+              },
+              prod={
+                  'read': 'name/some-type-of-very-long-name-for-reading-perms',
+                  'modify': 'name/some-other-type-of-very-long-name-for-modifying'
+              })
+        """)
+    uwlines = yapf_test_helper.ParseAndUnwrap(unformatted_code)
+    self.assertCodeEqual(expected_formatted_code, reformatter.Reformat(uwlines))
+
+  def testB34682902(self):
+    unformatted_code = textwrap.dedent("""\
+        logging.info("Mean angular velocity norm: %.3f", np.linalg.norm(np.mean(ang_vel_arr, axis=0)))
+        """)
+    expected_formatted_code = textwrap.dedent("""\
+        logging.info("Mean angular velocity norm: %.3f",
+                     np.linalg.norm(np.mean(ang_vel_arr, axis=0)))
+        """)
+    uwlines = yapf_test_helper.ParseAndUnwrap(unformatted_code)
+    self.assertCodeEqual(expected_formatted_code, reformatter.Reformat(uwlines))
+
+  def testB33842726(self):
+    unformatted_code = textwrap.dedent("""\
+        class _():
+          def _():
+            hints.append(('hg tag -f -l -r %s %s # %s' % (short(ctx.node(
+            )), candidatetag, firstline))[:78])
+        """)
+    expected_formatted_code = textwrap.dedent("""\
+        class _():
+          def _():
+            hints.append(('hg tag -f -l -r %s %s # %s' %
+                          (short(ctx.node()), candidatetag, firstline))[:78])
+        """)
+    uwlines = yapf_test_helper.ParseAndUnwrap(unformatted_code)
+    self.assertCodeEqual(expected_formatted_code, reformatter.Reformat(uwlines))
+
   def testB32931780(self):
     unformatted_code = textwrap.dedent("""\
         environments = {
@@ -71,8 +162,9 @@ class BuganizerFixes(yapf_test_helper.YAPFTest):
                 'who': 'allin',
                 # This is an entry that has a dictionary in it. It's ugly
                 'something': {
-                    'page':
-                        ['this-is-a-page@xxxxxxxx.com', 'something-for-eml@xxxxxx.com'],
+                    'page': [
+                        'this-is-a-page@xxxxxxxx.com', 'something-for-eml@xxxxxx.com'
+                    ],
                     'bug': ['bugs-go-here5300@xxxxxx.com'],
                     'email': ['sometypeof-email@xxxxxx.com'],
                 },
@@ -391,12 +483,9 @@ class BuganizerFixes(yapf_test_helper.YAPFTest):
     expected_formatted_code = textwrap.dedent("""\
         if True:
           query.fetch_page.assert_has_calls([
-              mock.call(
-                  100, start_cursor=None),
-              mock.call(
-                  100, start_cursor=cursor_1),
-              mock.call(
-                  100, start_cursor=cursor_2),
+              mock.call(100, start_cursor=None),
+              mock.call(100, start_cursor=cursor_1),
+              mock.call(100, start_cursor=cursor_2),
           ])
         """)
     uwlines = yapf_test_helper.ParseAndUnwrap(unformatted_code)
@@ -672,27 +761,22 @@ class BuganizerFixes(yapf_test_helper.YAPFTest):
   def testB28414371(self):
     code = textwrap.dedent("""\
         def _():
-          return (
-              (m.fffff(
-                  m.rrr('mmmmmmmmmmmmmmmm', 'ssssssssssssssssssssssssss'),
-                  ffffffffffffffff)
-               | m.wwwwww(m.ddddd('1h'))
-               | m.ggggggg(bbbbbbbbbbbbbbb)
-               | m.ppppp(
-                   (1 - m.ffffffffffffffff(llllllllllllllllllllll * 1000000, m.vvv)) *
-                   m.ddddddddddddddddd(m.vvv)), m.fffff(
-                       m.rrr('mmmmmmmmmmmmmmmm', 'sssssssssssssssssssssss'),
-                       dict(
-                           ffffffffffffffff,
-                           **{
+          return ((m.fffff(
+              m.rrr('mmmmmmmmmmmmmmmm', 'ssssssssssssssssssssssssss'), ffffffffffffffff)
+                   | m.wwwwww(m.ddddd('1h'))
+                   | m.ggggggg(bbbbbbbbbbbbbbb)
+                   | m.ppppp(
+                       (1 - m.ffffffffffffffff(llllllllllllllllllllll * 1000000, m.vvv))
+                       * m.ddddddddddddddddd(m.vvv)), m.fffff(
+                           m.rrr('mmmmmmmmmmmmmmmm', 'sssssssssssssssssssssss'),
+                           dict(ffffffffffffffff, **{
                                'mmmmmm:ssssss':
-                                   m.rrrrrrrrrrr(
-                                       '|'.join(iiiiiiiiiiiiii), iiiiii=True)
+                                   m.rrrrrrrrrrr('|'.join(iiiiiiiiiiiiii), iiiiii=True)
                            }))
-               | m.wwwwww(m.rrrr('1h'))
-               | m.ggggggg(bbbbbbbbbbbbbbb))
-              | m.jjjj()
-              | m.ppppp(m.vvv[0] + m.vvv[1]))
+                   | m.wwwwww(m.rrrr('1h'))
+                   | m.ggggggg(bbbbbbbbbbbbbbb))
+                  | m.jjjj()
+                  | m.ppppp(m.vvv[0] + m.vvv[1]))
         """)
     uwlines = yapf_test_helper.ParseAndUnwrap(code)
     self.assertCodeEqual(code, reformatter.Reformat(uwlines))
@@ -951,8 +1035,9 @@ class BuganizerFixes(yapf_test_helper.YAPFTest):
 
   def testB19194420(self):
     code = textwrap.dedent("""\
-        method.Set('long argument goes here that causes the line to break',
-                   lambda arg2=0.5: arg2)
+        method.Set(
+            'long argument goes here that causes the line to break',
+            lambda arg2=0.5: arg2)
         """)
     uwlines = yapf_test_helper.ParseAndUnwrap(code)
     self.assertCodeEqual(code, reformatter.Reformat(uwlines))
