@@ -27,7 +27,6 @@ UNBREAKABLE = split_penalty.UNBREAKABLE
 VERY_STRONGLY_CONNECTED = split_penalty.VERY_STRONGLY_CONNECTED
 DOTTED_NAME = split_penalty.DOTTED_NAME
 STRONGLY_CONNECTED = split_penalty.STRONGLY_CONNECTED
-CONTIGUOUS_LIST = split_penalty.CONTIGUOUS_LIST
 
 
 class SplitPenaltyTest(unittest.TestCase):
@@ -191,18 +190,18 @@ class SplitPenaltyTest(unittest.TestCase):
     tree = self._ParseAndComputePenalties(code)
     self._CheckPenalties(tree, [
         ('[', None),
-        ('a', STRONGLY_CONNECTED),
-        ('for', STRONGLY_CONNECTED),
+        ('a', None),
+        ('for', 0),
         ('a', STRONGLY_CONNECTED),
         ('in', STRONGLY_CONNECTED),
         ('foo', STRONGLY_CONNECTED),
-        ('if', STRONGLY_CONNECTED),
+        ('if', 0),
         ('a', STRONGLY_CONNECTED),
         ('.', UNBREAKABLE),
         ('x', DOTTED_NAME),
         ('==', STRONGLY_CONNECTED),
         ('37', STRONGLY_CONNECTED),
-        (']', STRONGLY_CONNECTED),
+        (']', None),
     ])
 
   def testFuncCalls(self):
@@ -211,11 +210,11 @@ class SplitPenaltyTest(unittest.TestCase):
     self._CheckPenalties(tree, [
         ('foo', None),
         ('(', UNBREAKABLE),
-        ('1', CONTIGUOUS_LIST),
-        (',', CONTIGUOUS_LIST),
-        ('2', CONTIGUOUS_LIST),
-        (',', CONTIGUOUS_LIST),
-        ('3', CONTIGUOUS_LIST),
+        ('1', None),
+        (',', UNBREAKABLE),
+        ('2', None),
+        (',', UNBREAKABLE),
+        ('3', None),
         (')', VERY_STRONGLY_CONNECTED),
     ])
 
@@ -229,11 +228,11 @@ class SplitPenaltyTest(unittest.TestCase):
         ('.', STRONGLY_CONNECTED),
         ('baz', DOTTED_NAME),
         ('(', STRONGLY_CONNECTED),
-        ('1', CONTIGUOUS_LIST),
-        (',', CONTIGUOUS_LIST),
-        ('2', CONTIGUOUS_LIST),
-        (',', CONTIGUOUS_LIST),
-        ('3', CONTIGUOUS_LIST),
+        ('1', None),
+        (',', UNBREAKABLE),
+        ('2', None),
+        (',', UNBREAKABLE),
+        ('3', None),
         (')', VERY_STRONGLY_CONNECTED),
     ])
 
